var oRequest           = new Object();    // リクエスト情報オブジェクト
var oRequestJSON;                         // リクエスト情報オブジェクト(JSON文字列)
var oCaption           = new Object();    // 画面表示文言オブジェクト
var oMessage           = new Object();    // 画面表示メッセージオブジェクト
var oValidationJSON    = new Object();    // 入力チェック用オブジェクト(JSON文字列)


//=============================================================================
// ファイルアップロード画面　初期化関数
//   【 入力 】request: ＵＲＬ引数取得オブジェクト
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】ファイルアップロード画面を表示します。
//=============================================================================
function init(request) {

    // セッション情報
    var sessionInfo = AccessSecurityManager.getSessionInfo();
    var groupId = sessionInfo.loginGroup;
    var userCode = sessionInfo.user;

    // 入力チェック用オブジェクトの生成
    setValidation(sessionInfo);

    // リクエストパラメータ取得
    oRequest.imwGroupId              = groupId;
    oRequest.imwUserCode             = userCode;
    oRequest.resultStatus            = Procedure.imw_utils.getValue(request.resultStatus, "0");
    oRequest.messageId               = Procedure.imw_utils.getValue(request.messageId, "");
    oRequest.systemFileName          = Procedure.imw_utils.getValue(request.systemFileName, "");
    oRequest.realFileName            = Procedure.imw_utils.getValue(request.realFileName, "");
    oRequest.fileSize                = Procedure.imw_utils.getValue(request.fileSize, "");

    if(oRequest.resultStatus == "-1") {
        // ファイルアップロードでエラー発生：メッセージ取得
        oRequest.message = MessageManager.getMessage(oRequest.messageId);
    }

    // 画面表示キャプション取得
    getCaption();

    // 画面表示メッセージ取得
    getMessage();

    // リクエストパラメータをJSON文字列に変換
    oRequestJSON = Procedure.imw_utils.escapeHTML(ImJson.toJSONString(oRequest));

    // HTML特殊文字を変換する
    oRequest = Procedure.imw_utils.toBrowse(oRequest);

}


//=============================================================================
// 入力チェック用オブジェクト　生成関数
//   【 入力 】sessionInfo : セッション情報オブジェクト
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
// 【参考】指定可能なプロパティ
// name         = チェック対象となるHTML上のname属性値 (必須)
// messageId    = 項目名を示すメッセージID。配列可
// userManualId = ユーザ定義のメッセージID。省略時は共通チェックを行う
// multiLocale  = 国際化対応項目かどうか。true/false。省略時はfalse
// requireInput = 必須入力項目かどうか。true/false。省略時はfalse
// requireSelect= 必須選択項目かどうか。true/false。省略時はfalse
// maxLength    = 最大入力可能文字数。省略時は0 (チェックなし)
// minLength    = 最小入力可能文字数。省略時は0
// alphaFormat  = 半角英数字チェックを行うかどうか。true/false。省略時はfalse
// numFormat    = 半角数字チェックを行うかどうか。true/false。省略時はfalse
// dateFormat   = 日付型チェックを行うかどうか。true/false。省略時はfalse
// numRange     = 数値範囲チェックを行うかどうか。true/false。省略時はfalse
// dateRange    = 日付範囲チェックを行うかどうか。true/false。省略時はfalse
//=============================================================================
function setValidation(sessionInfo) {

    // ロケールオブジェクトの生成(共通関数への引き渡し情報として利用)
    var localeId = sessionInfo.locale;
    var localeObj = {
        "localeId" : localeId,
        "locales"  : System.getLocales(localeId)
    };

    var groupId = sessionInfo.loginGroup;
    var objValidateParameter;
    var objValidation = new Object();

    // 各入力項目のチェック用情報を設定

    // ファイル名
    objValidateParameter = Procedure.imw_validate_utils.makeParameter4InputRequireAttachFileName("realFileName", "IMW.CAP.1001");
    Procedure.imw_validate_utils.setParameterFromSettings(groupId, objValidateParameter, "attach-file-name");
    Procedure.imw_validate_utils.makeValidateMessage(objValidation, localeObj, objValidateParameter);

    // ファイル保存名
    objValidateParameter = Procedure.imw_validate_utils.makeParameter4AttachFileName("saveFileName", "IMW.CAP.1014");
    Procedure.imw_validate_utils.setParameterFromSettings(groupId, objValidateParameter, "attach-file-name");
    Procedure.imw_validate_utils.makeValidateMessage(objValidation, localeObj, objValidateParameter);

    // 入力チェックcsjsの引数として有効な形式に変換
    var objValidateMsg = new Object();
    for(var cnt=0; cnt<objValidation.messageList.length; cnt++) {
        objValidateMsg[ Procedure.imw_utils.toBrowse(objValidation.messageList[cnt].key) ] = 
            Procedure.imw_utils.toBrowse(objValidation.messageList[cnt].msg);
    }

    // JSON文字列に変換
    oValidationJSON = Procedure.imw_utils.escapeHTML(ImJson.toJSONString(objValidateMsg));
}


//=============================================================================
// ファイルアップロード関数
//   【 入力 】request: ＵＲＬ引数取得オブジェクト
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】ローカルファイルをアップロードします。
//=============================================================================
function uploadFile(request) {

    var selfPagePath = "workflow/common/unit/file/file_upload";

    // セッション情報
    var sessionInfo = AccessSecurityManager.getSessionInfo();
    var groupId = sessionInfo.loginGroup;
    var userCode = sessionInfo.user;

    // 処理結果オブジェクトの生成
    var objResult = { "imwGroupId"     : groupId,
                      "imwUserCode"    : userCode,
                      "tempDirKey"     : request.tempDirKey,
                      "resultStatus"   : "0",
                      "messageId"      : "",
                      "systemFileName" : "",
                      "realFileName"   : "",
                      "fileSize"       : ""
    };

    // ファイルの実体を取得
    var fileStream = request.getParameter("localFilePath").getValueAsStream();
    if (isBlank(fileStream)) {
        // 指定ファイルが存在しない、もしくはファイルサイズが0バイト
        objResult.resultStatus = "-1";
        objResult.messageId    = "IMW.CLI.WRN.3522";

        forward(selfPagePath, objResult);
    }

    // 実ファイル名の取得
    var realFileName;
    var fileSaveName = Procedure.imw_utils.trim(request.fileSaveName);
    if(isBlank(fileSaveName)) {
        // 保存ファイル名指定なし
        realFileName = request.fileName.substring(
                                request.fileName.lastIndexOf("\\")+1);
    } else {
        // 保存ファイル名指定あり
        realFileName = request.fileSaveName;
    }

    // ファイルアップロード
    var attachFileManager = new WorkflowAttachFileManager(groupId, userCode);
    var result = attachFileManager.addFileToTemp(request.tempDirKey, realFileName, fileStream);
    if(!result.resultFlag) {
        // アップロード失敗
        objResult.resultStatus = "-1";
        objResult.messageId = result.resultStatus.messageId;

        forward(selfPagePath, objResult);
    }

    // 正常終了：処理結果の格納
    objResult.resultStatus   =  "1";
    objResult.systemFileName = result.data.systemFileName;
    objResult.realFileName   = result.data.realFileName;
    objResult.fileSize       = result.data.fileSize;

    // 自画面再表示
    forward(selfPagePath, objResult);
}



//=============================================================================
// 画面表示キャプション　取得関数
//   【 入力 】なし
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】画面表示キャプション取得処理を実行します。
//=============================================================================
function getCaption() {
    oCaption.add            = MessageManager.getMessage("IMW.CAP.1012"); // 追 加
    oCaption.uploadFile     = MessageManager.getMessage("IMW.CAP.1013"); // アップロードファイル
    oCaption.fileSaveName   = MessageManager.getMessage("IMW.CAP.1014"); // ファイル保存名
}



//=============================================================================
// 画面表示メッセージ　取得関数
//   【 入力 】なし
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】画面表示メッセージ取得処理を実行します。
//=============================================================================
function getMessage() {
    oMessage.pleaseSelect = MessageManager.getMessage("IMW.CLI.INF.3500"); // アップロードするファイルを指定してください。
}



//=============================================================================
// 添付ファイル　削除関数
//   【 入力 】request: ＵＲＬ引数取得オブジェクト
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】添付ファイルを一時領域から削除します。
//             jsspRpcによって各種処理画面から呼び出される処理です。
//=============================================================================
function deleteAttachFileFromTemp(request) {

    // セッション情報
    var sessionInfo = AccessSecurityManager.getSessionInfo();
    var groupId = sessionInfo.loginGroup;
    var userCode = sessionInfo.user;

    var tempDirKey     = request.tempDirKey;
    var systemFileName = request.systemFileName;

    // 添付ファイルの削除
    var attachFileManager = new WorkflowAttachFileManager(groupId, userCode);
    var result = attachFileManager.removeTempFile(tempDirKey, systemFileName);
    if(!result.resultFlag) {
        // 削除失敗
        result.resultStatus.message = MessageManager.getMessage(result.resultStatus.messageId);
    }

    return result;
}



//=============================================================================
// セッションタイムアウト確認関数
//   【 入力 】なし
//   【 返却 】なし
//   【作成者】NTT DATA INTRAMART
//   【 概要 】標準処理画面のファイルアップロード部品からのセッションタイムアウト確認で呼び出される処理です。
//             当関数自体は特段の処理を行いません。
//             セッションタイムアウト状態の場合、当関数の処理は実行されずにレスポンスが返却されます。
//=============================================================================
function checkSessionTimeout() {
    return;
}
